@@ -1,5 +1,4 @@
 """Algorithms to support fitting routines in seaborn plotting functions."""
-from __future__ import division
 import numbers
 import numpy as np
 import warnings
@@ -81,7 +80,7 @@ def bootstrap(*args, **kwargs):
 
     boot_dist = []
     for i in range(int(n_boot)):
-        resampler = integers(0, n, n)
+        resampler = integers(0, n, n, dtype=np.intp)  # intp is indexing dtype
         sample = [a.take(resampler, axis=0) for a in args]
         boot_dist.append(f(*sample, **func_kwargs))
     return np.array(boot_dist)
@@ -96,12 +95,11 @@ def _structured_bootstrap(args, n_boot, units, func, func_kwargs, integers):
 
     boot_dist = []
     for i in range(int(n_boot)):
-        resampler = integers(0, n_units, n_units)
-        sample = [np.take(a, resampler, axis=0) for a in args]
+        resampler = integers(0, n_units, n_units, dtype=np.intp)
+        sample = [[a[i] for i in resampler] for a in args]
         lengths = map(len, sample[0])
-        resampler = [integers(0, n, n) for n in lengths]
-        sample = [[c.take(r, axis=0) for c, r in zip(a, resampler)]
-                  for a in sample]
+        resampler = [integers(0, n, n, dtype=np.intp) for n in lengths]
+        sample = [[c.take(r, axis=0) for c, r in zip(a, resampler)] for a in sample]
         sample = list(map(np.concatenate, sample))
         boot_dist.append(func(*sample, **func_kwargs))
     return np.array(boot_dist)
