@@ -3,7 +3,6 @@ import numpy as np
 import matplotlib as mpl
 
 import pytest
-import nose.tools as nt
 import numpy.testing as npt
 
 from .. import palettes, utils, rcmod
@@ -11,7 +10,7 @@ from ..external import husl
 from ..colors import xkcd_rgb, crayons
 
 
-class TestColorPalettes(object):
+class TestColorPalettes:
 
     def test_current_palette(self):
 
@@ -26,9 +25,9 @@ class TestColorPalettes(object):
         context_pal = palettes.color_palette("muted")
 
         with palettes.color_palette(context_pal):
-            nt.assert_equal(utils.get_color_cycle(), context_pal)
+            assert utils.get_color_cycle() == context_pal
 
-        nt.assert_equal(utils.get_color_cycle(), default_pal)
+        assert utils.get_color_cycle() == default_pal
 
     def test_big_palette_context(self):
 
@@ -37,9 +36,9 @@ class TestColorPalettes(object):
 
         rcmod.set_palette(original_pal)
         with palettes.color_palette(context_pal, 10):
-            nt.assert_equal(utils.get_color_cycle(), context_pal)
+            assert utils.get_color_cycle() == context_pal
 
-        nt.assert_equal(utils.get_color_cycle(), original_pal)
+        assert utils.get_color_cycle() == original_pal
 
         # Reset default
         rcmod.set()
@@ -72,21 +71,35 @@ class TestColorPalettes(object):
 
     def test_hls_palette(self):
 
-        hls_pal1 = palettes.hls_palette()
-        hls_pal2 = palettes.color_palette("hls")
-        npt.assert_array_equal(hls_pal1, hls_pal2)
+        pal1 = palettes.hls_palette()
+        pal2 = palettes.color_palette("hls")
+        npt.assert_array_equal(pal1, pal2)
+
+        cmap1 = palettes.hls_palette(as_cmap=True)
+        cmap2 = palettes.color_palette("hls", as_cmap=True)
+        npt.assert_array_equal(cmap1([.2, .8]), cmap2([.2, .8]))
 
     def test_husl_palette(self):
 
-        husl_pal1 = palettes.husl_palette()
-        husl_pal2 = palettes.color_palette("husl")
-        npt.assert_array_equal(husl_pal1, husl_pal2)
+        pal1 = palettes.husl_palette()
+        pal2 = palettes.color_palette("husl")
+        npt.assert_array_equal(pal1, pal2)
+
+        cmap1 = palettes.husl_palette(as_cmap=True)
+        cmap2 = palettes.color_palette("husl", as_cmap=True)
+        npt.assert_array_equal(cmap1([.2, .8]), cmap2([.2, .8]))
 
     def test_mpl_palette(self):
 
-        mpl_pal1 = palettes.mpl_palette("Reds")
-        mpl_pal2 = palettes.color_palette("Reds")
-        npt.assert_array_equal(mpl_pal1, mpl_pal2)
+        pal1 = palettes.mpl_palette("Reds")
+        pal2 = palettes.color_palette("Reds")
+        npt.assert_array_equal(pal1, pal2)
+
+        cmap1 = mpl.cm.get_cmap("Reds")
+        cmap2 = palettes.mpl_palette("Reds", as_cmap=True)
+        cmap3 = palettes.color_palette("Reds", as_cmap=True)
+        npt.assert_array_equal(cmap1, cmap2)
+        npt.assert_array_equal(cmap1, cmap3)
 
     def test_mpl_dark_palette(self):
 
@@ -94,20 +107,24 @@ class TestColorPalettes(object):
         mpl_pal2 = palettes.color_palette("Blues_d")
         npt.assert_array_equal(mpl_pal1, mpl_pal2)
 
+        mpl_pal1 = palettes.mpl_palette("Blues_r_d")
+        mpl_pal2 = palettes.color_palette("Blues_r_d")
+        npt.assert_array_equal(mpl_pal1, mpl_pal2)
+
     def test_bad_palette_name(self):
 
-        with nt.assert_raises(ValueError):
+        with pytest.raises(ValueError):
             palettes.color_palette("IAmNotAPalette")
 
     def test_terrible_palette_name(self):
 
-        with nt.assert_raises(ValueError):
+        with pytest.raises(ValueError):
             palettes.color_palette("jet")
 
     def test_bad_palette_colors(self):
 
         pal = ["red", "blue", "iamnotacolor"]
-        with nt.assert_raises(ValueError):
+        with pytest.raises(ValueError):
             palettes.color_palette(pal)
 
     def test_palette_desat(self):
@@ -122,16 +139,16 @@ class TestColorPalettes(object):
         pal_in = np.array(["red", "blue", "green"])
         pal_out = palettes.color_palette(pal_in, 3)
 
-        nt.assert_is_instance(pal_out, list)
-        nt.assert_is_instance(pal_out[0], tuple)
-        nt.assert_is_instance(pal_out[0][0], float)
-        nt.assert_equal(len(pal_out[0]), 3)
+        assert isinstance(pal_out, list)
+        assert isinstance(pal_out[0], tuple)
+        assert isinstance(pal_out[0][0], float)
+        assert len(pal_out[0]) == 3
 
     def test_palette_cycles(self):
 
         deep = palettes.color_palette("deep6")
         double_deep = palettes.color_palette("deep6", 12)
-        nt.assert_equal(double_deep, deep + deep)
+        assert double_deep == deep + deep
 
     def test_hls_values(self):
 
@@ -171,11 +188,11 @@ class TestColorPalettes(object):
 
         pal_short = palettes.mpl_palette("Set1", 4)
         pal_long = palettes.mpl_palette("Set1", 6)
-        nt.assert_equal(pal_short, pal_long[:4])
+        assert pal_short == pal_long[:4]
 
         pal_full = palettes.mpl_palette("Set2", 8)
         pal_long = palettes.mpl_palette("Set2", 10)
-        nt.assert_equal(pal_full, pal_long[:8])
+        assert pal_full == pal_long[:8]
 
     def test_mpl_reversal(self):
 
@@ -188,7 +205,7 @@ class TestColorPalettes(object):
         color = .5, .8, .4
         rgb_got = palettes._color_to_rgb(color, "hls")
         rgb_want = colorsys.hls_to_rgb(*color)
-        nt.assert_equal(rgb_got, rgb_want)
+        assert rgb_got == rgb_want
 
     def test_rgb_from_husl(self):
 
@@ -207,33 +224,61 @@ class TestColorPalettes(object):
 
         color = "dull red"
         rgb_got = palettes._color_to_rgb(color, "xkcd")
-        rgb_want = xkcd_rgb[color]
-        nt.assert_equal(rgb_got, rgb_want)
+        rgb_want = mpl.colors.to_rgb(xkcd_rgb[color])
+        assert rgb_got == rgb_want
 
     def test_light_palette(self):
 
-        pal_forward = palettes.light_palette("red")
-        pal_reverse = palettes.light_palette("red", reverse=True)
-        assert np.allclose(pal_forward, pal_reverse[::-1])
-
-        red = mpl.colors.colorConverter.to_rgb("red")
-        nt.assert_equal(pal_forward[-1], red)
-
-        pal_cmap = palettes.light_palette("blue", as_cmap=True)
-        nt.assert_is_instance(pal_cmap, mpl.colors.LinearSegmentedColormap)
-
-    def test_dark_palette(self):
-
-        pal_forward = palettes.dark_palette("red")
-        pal_reverse = palettes.dark_palette("red", reverse=True)
+        n = 4
+        pal_forward = palettes.light_palette("red", n)
+        pal_reverse = palettes.light_palette("red", n, reverse=True)
         assert np.allclose(pal_forward, pal_reverse[::-1])
 
         red = mpl.colors.colorConverter.to_rgb("red")
         assert pal_forward[-1] == red
 
+        pal_f_from_string = palettes.color_palette("light:red", n)
+        assert pal_forward[3] == pal_f_from_string[3]
+
+        pal_r_from_string = palettes.color_palette("light:red_r", n)
+        assert pal_reverse[3] == pal_r_from_string[3]
+
+        pal_cmap = palettes.light_palette("blue", as_cmap=True)
+        assert isinstance(pal_cmap, mpl.colors.LinearSegmentedColormap)
+
+        pal_cmap_from_string = palettes.color_palette("light:blue", as_cmap=True)
+        assert pal_cmap(.8) == pal_cmap_from_string(.8)
+
+        pal_cmap = palettes.light_palette("blue", as_cmap=True, reverse=True)
+        pal_cmap_from_string = palettes.color_palette("light:blue_r", as_cmap=True)
+        assert pal_cmap(.8) == pal_cmap_from_string(.8)
+
+    def test_dark_palette(self):
+
+        n = 4
+        pal_forward = palettes.dark_palette("red", n)
+        pal_reverse = palettes.dark_palette("red", n, reverse=True)
+        assert np.allclose(pal_forward, pal_reverse[::-1])
+
+        red = mpl.colors.colorConverter.to_rgb("red")
+        assert pal_forward[-1] == red
+
+        pal_f_from_string = palettes.color_palette("dark:red", n)
+        assert pal_forward[3] == pal_f_from_string[3]
+
+        pal_r_from_string = palettes.color_palette("dark:red_r", n)
+        assert pal_reverse[3] == pal_r_from_string[3]
+
         pal_cmap = palettes.dark_palette("blue", as_cmap=True)
         assert isinstance(pal_cmap, mpl.colors.LinearSegmentedColormap)
 
+        pal_cmap_from_string = palettes.color_palette("dark:blue", as_cmap=True)
+        assert pal_cmap(.8) == pal_cmap_from_string(.8)
+
+        pal_cmap = palettes.dark_palette("blue", as_cmap=True, reverse=True)
+        pal_cmap_from_string = palettes.color_palette("dark:blue_r", as_cmap=True)
+        assert pal_cmap(.8) == pal_cmap_from_string(.8)
+
     def test_diverging_palette(self):
 
         h_neg, h_pos = 100, 200
@@ -241,7 +286,7 @@ class TestColorPalettes(object):
         args = h_neg, h_pos, sat, lum
 
         n = 12
-        pal = palettes.diverging_palette(*args,  n=n)
+        pal = palettes.diverging_palette(*args, n=n)
         neg_pal = palettes.light_palette((h_neg, sat, lum), int(n // 2),
                                          input="husl")
         pos_pal = palettes.light_palette((h_pos, sat, lum), int(n // 2),
@@ -260,7 +305,13 @@ class TestColorPalettes(object):
 
         colors = ["red", "yellow", "white"]
         pal_cmap = palettes.blend_palette(colors, as_cmap=True)
-        nt.assert_is_instance(pal_cmap, mpl.colors.LinearSegmentedColormap)
+        assert isinstance(pal_cmap, mpl.colors.LinearSegmentedColormap)
+
+        colors = ["red", "blue"]
+        pal = palettes.blend_palette(colors)
+        pal_str = "blend:" + ",".join(colors)
+        pal_from_str = palettes.color_palette(pal_str)
+        assert pal == pal_from_str
 
     def test_cubehelix_against_matplotlib(self):
 
@@ -270,24 +321,24 @@ class TestColorPalettes(object):
         sns_pal = palettes.cubehelix_palette(8, start=0.5, rot=-1.5, hue=1,
                                              dark=0, light=1, reverse=True)
 
-        nt.assert_list_equal(sns_pal, mpl_pal)
+        assert sns_pal == mpl_pal
 
     def test_cubehelix_n_colors(self):
 
         for n in [3, 5, 8]:
             pal = palettes.cubehelix_palette(n)
-            nt.assert_equal(len(pal), n)
+            assert len(pal) == n
 
     def test_cubehelix_reverse(self):
 
         pal_forward = palettes.cubehelix_palette()
         pal_reverse = palettes.cubehelix_palette(reverse=True)
-        nt.assert_list_equal(pal_forward, pal_reverse[::-1])
+        assert pal_forward == pal_reverse[::-1]
 
     def test_cubehelix_cmap(self):
 
         cmap = palettes.cubehelix_palette(as_cmap=True)
-        nt.assert_is_instance(cmap, mpl.colors.ListedColormap)
+        assert isinstance(cmap, mpl.colors.ListedColormap)
         pal = palettes.cubehelix_palette()
         x = np.linspace(0, 1, 6)
         npt.assert_array_equal(cmap(x)[:, :3], pal)
@@ -296,7 +347,7 @@ class TestColorPalettes(object):
         x = np.linspace(0, 1, 6)
         pal_forward = cmap(x).tolist()
         pal_reverse = cmap_rev(x[::-1]).tolist()
-        nt.assert_list_equal(pal_forward, pal_reverse)
+        assert pal_forward == pal_reverse
 
     def test_cubehelix_code(self):
 
@@ -319,13 +370,17 @@ class TestColorPalettes(object):
         pal2 = color_palette(cubehelix_palette(6, reverse=True))
         assert pal1 == pal2
 
+        pal1 = color_palette("ch:_r", as_cmap=True)
+        pal2 = cubehelix_palette(6, reverse=True, as_cmap=True)
+        assert pal1(.5) == pal2(.5)
+
     def test_xkcd_palette(self):
 
         names = list(xkcd_rgb.keys())[10:15]
         colors = palettes.xkcd_palette(names)
         for name, color in zip(names, colors):
             as_hex = mpl.colors.rgb2hex(color)
-            nt.assert_equal(as_hex, xkcd_rgb[name])
+            assert as_hex == xkcd_rgb[name]
 
     def test_crayon_palette(self):
 
@@ -333,7 +388,7 @@ class TestColorPalettes(object):
         colors = palettes.crayon_palette(names)
         for name, color in zip(names, colors):
             as_hex = mpl.colors.rgb2hex(color)
-            nt.assert_equal(as_hex, crayons[name].lower())
+            assert as_hex == crayons[name].lower()
 
     def test_color_codes(self):
 
@@ -342,7 +397,7 @@ class TestColorPalettes(object):
         for code, color in zip("bgrmyck", colors):
             rgb_want = mpl.colors.colorConverter.to_rgb(color)
             rgb_got = mpl.colors.colorConverter.to_rgb(code)
-            nt.assert_equal(rgb_want, rgb_got)
+            assert rgb_want == rgb_got
         palettes.set_color_codes("reset")
 
         with pytest.raises(ValueError):
@@ -352,10 +407,17 @@ class TestColorPalettes(object):
 
         pal = palettes.color_palette("deep")
         for rgb, hex in zip(pal, pal.as_hex()):
-            nt.assert_equal(mpl.colors.rgb2hex(rgb), hex)
+            assert mpl.colors.rgb2hex(rgb) == hex
 
     def test_preserved_palette_length(self):
 
         pal_in = palettes.color_palette("Set1", 10)
         pal_out = palettes.color_palette(pal_in)
-        nt.assert_equal(pal_in, pal_out)
+        assert pal_in == pal_out
+
+    def test_html_rep(self):
+
+        pal = palettes.color_palette()
+        html = pal._repr_html_()
+        for color in pal.as_hex():
+            assert color in html
